@@ -1,5 +1,5 @@
 """
-@author: Thomas Delaet <thomas@delaet.org>
+:author: Thomas Delaet <thomas@delaet.org>
 """
 import velbus
 
@@ -12,7 +12,7 @@ class ModuleTypeRequestMessage(velbus.Message):
 
     def populate(self, priority, address, rtr, data):
         """
-        @return: None
+        :return: None
         """
         assert isinstance(data, bytes)
         self.needs_low_priority(priority)
@@ -20,8 +20,14 @@ class ModuleTypeRequestMessage(velbus.Message):
         self.needs_no_data(data)
         self.set_attributes(priority, address, rtr)
 
+    def set_defaults(self, address):
+        if address is not None:
+            self.set_address(address)
+        self.set_low_priority()
+        self.set_rtr()
+
     def data_to_binary(self):
         """
-        @return: bytes
+        :return: bytes
         """
         return bytes([])
