@@ -5,7 +5,7 @@
 from velbus.modules.vmb4ry import VMB4RYModule
 from velbus.modules.vmbin import VMB6INModule
 from velbus.modules.vmbin import VMB7INModule
-from velbus.modules.vmbgp import VMBGPxModule
+from velbus.modules.vmbgp import VMBGPxModule, VMBGPxDModule
 from velbus.modules.vmbpbn import VMB2PBNModule
 from velbus.modules.vmbpbn import VMB6PBNModule
 from velbus.modules.vmb1ts import VMB1TSModule
